@@ -22,6 +22,9 @@ class CodeGenerator(CodeGeneratorBase):
         auth_features: bool = False,
         for_git_repo: bool = False,
     ) -> None:
+        if not package_name.isidentifier():
+            raise ValueError(f"Package name must be a valid Python identifier, was {package_name!r}")
+
         # remove duplicate features
         if lock_controller:
             features = [
@@ -50,8 +53,8 @@ class CodeGenerator(CodeGeneratorBase):
         self.generate_directory(implementations_dir)
 
         # generate setup files
-        self._generate_manifest(package_name, out_dir)
-        self._generate_setup(package_name, out_dir)
+        self._generate_pyproject_toml(package_name, out_dir)
+        self._generate_setup_cfg(package_name, out_dir)
 
         # generate git repo files
         if for_git_repo:
@@ -116,16 +119,16 @@ class CodeGenerator(CodeGeneratorBase):
             feature_generator.generate_impl(out_dir, prefix=prefix)
             self.generated_files.extend(feature_generator.generated_files)
 
-    def _generate_manifest(self, package_name: str, out_dir: str) -> None:
+    def _generate_pyproject_toml(self, package_name: str, out_dir: str) -> None:
         self.generate_file(
-            join(out_dir, "MANIFEST.in"),
-            self.template_env.get_template("package/manifest").render(package_name=package_name),
+            join(out_dir, "pyproject.toml"),
+            self.template_env.get_template("package/pyproject_toml").render(),
         )
 
-    def _generate_setup(self, package_name: str, out_dir: str) -> None:
+    def _generate_setup_cfg(self, package_name: str, out_dir: str) -> None:
         self.generate_file(
-            join(out_dir, "setup.py"),
-            self.template_env.get_template("package/setup").render(package_name=package_name),
+            join(out_dir, "setup.cfg"),
+            self.template_env.get_template("package/setup_cfg").render(package_name=package_name),
         )
 
     def _generate_main(self, package_name: str, out_dir: str) -> None:
