@@ -46,30 +46,38 @@ class SilaServiceListener(ServiceListener):
             return
 
         service_name = service_info.name
+        service_uuid = UUID(service_name.split(".")[0])
         ip_address = service_info.parsed_addresses()[0]
+        port = service_info.port
 
         try:
             ca = self.__get_ca_from_service_info(service_info)
 
             if ca is not None:
-                self.services[service_name] = SilaClient(ip_address, service_info.port, root_certs=ca)
-            elif any(par is not None for par in (self.cert_chain, self.private_key, self.root_certs)):
+                self.services[service_name] = SilaClient(ip_address, port, root_certs=ca)
+                warnings.warn(
+                    RuntimeWarning(
+                        f"Connected to server at {ip_address}:{port} with UUID {service_uuid} via untrusted certificate"
+                    )
+                )
+            elif self.cert_chain is not None or self.private_key is not None or self.root_certs is not None:
                 self.services[service_name] = SilaClient(
                     ip_address,
-                    service_info.port,
+                    port,
                     cert_chain=self.cert_chain,
                     private_key=self.private_key,
                     root_certs=self.root_certs,
                 )
             elif self.insecure:
-                self.services[service_name] = SilaClient(ip_address, service_info.port, insecure=True)
+                self.services[service_name] = SilaClient(ip_address, port, insecure=True)
             else:
-                raise RuntimeError("Ignored unencrypted server")
+                warnings.warn(
+                    RuntimeWarning(f"Ignored unencrypted server at {ip_address}:{port} with UUID {service_uuid}")
+                )
         except Exception as ex:
-            service_uuid = UUID(service_name.split(".")[0])
             warnings.warn(
                 RuntimeWarning(
-                    f"SiLA Server Discovery found a service with UUID {service_uuid} but failed to connect to it: "
+                    f"Failed to connect to server at {ip_address}:{port} with UUID {service_uuid}: "
                     f"{ex.__class__.__name__} - {ex}"
                 )
             )
