@@ -13,20 +13,20 @@ if TYPE_CHECKING:
 
 
 class ValidationError(SilaError):
-    parameterfully_qualified_identifier: FullyQualifiedIdentifier
+    parameter_fully_qualified_identifier: FullyQualifiedIdentifier
     message: str
 
     def __init__(self, parameter: Parameter, message: str):
-        self.parameterfully_qualified_identifier = parameter.fully_qualified_identifier
+        self.parameter_fully_qualified_identifier = parameter.fully_qualified_identifier
         self.message = message
         super().__init__(
-            f"Constraint validation failed for parameter {self.parameterfully_qualified_identifier}: {message}"
+            f"Constraint validation failed for parameter {self.parameter_fully_qualified_identifier}: {message}"
         )
 
     def to_message(self) -> SiLAError:
         return self.pb2_module.SiLAError(
             validationError=self.pb2_module.ValidationError(
-                parameter=self.parameterfully_qualified_identifier, message=self.message
+                parameter=self.parameter_fully_qualified_identifier, message=self.message
             )
         )
 
