@@ -4,19 +4,18 @@ import os.path
 import re
 import sys
 import tempfile
-import warnings
 from base64 import standard_b64encode
 from collections import deque
 from contextlib import contextmanager
 from importlib import import_module
 from os.path import abspath, join
-from subprocess import PIPE, Popen
 from types import ModuleType
 from typing import TYPE_CHECKING, Generator, NoReturn, Tuple, Union
 
 import grpc
+from grpc_tools import protoc
 from lxml import etree
-from lxml.etree import XSLT, XMLParser, XMLSchema, _Element
+from lxml.etree import XSLT, XMLParser, XMLSchema, XSLTApplyError, _Element
 
 from sila2 import resource_dir
 
@@ -87,36 +86,19 @@ def run_protoc(proto_file: str) -> Tuple[ModuleType, ModuleType]:
     path, filename = os.path.split(abspath(proto_file))
     modulename, _ = os.path.splitext(filename)
 
-    include_framework = not proto_file.endswith("SiLAFramework.proto")
-
     with tempfile.TemporaryDirectory() as tmp_dir:
-        protoc_command = [
-            sys.executable,
-            "-m",
-            "grpc_tools.protoc",
+        protoc_args = [
+            "protoc",  # protoc expects args[0] to be the program name, which is irrelevant here and will be ignored
             f"--proto_path={path}",
             f"--proto_path={abspath(join(resource_dir, 'proto'))}",
             f"--python_out={tmp_dir}",
             f"--grpc_python_out={tmp_dir}",
             proto_file,
         ]
-        if include_framework:
-            protoc_command.append(abspath(join(resource_dir, "proto", "SiLAFramework.proto")))
-        protoc_process = Popen(protoc_command, encoding="UTF-8", stderr=PIPE)
-        _, protoc_stderr = protoc_process.communicate()
-
-        error_lines, warning_lines = [], []
-        for line in protoc_stderr.splitlines():
-            if "warn" in line.lower():
-                warning_lines.append(line)
-            else:
-                error_lines.append(line)
-
-        for warning in warning_lines:
-            warnings.warn(f"Warning during proto compilation: {warning}")
-
-        if protoc_process.returncode != 0:
-            raise RuntimeError(f"Failed to compile proto file {proto_file}: {os.linesep.join(error_lines)}")
+        if filename != "SiLAFramework.proto":
+            protoc_args.append(abspath(join(resource_dir, "proto", "SiLAFramework.proto")))
+        if protoc.main(protoc_args) != 0:
+            raise RuntimeError(f"Failed to compile proto file {proto_file}")
 
         with temporarily_add_to_path(tmp_dir):
             pb2_module = import_module(f"{modulename}_pb2")
@@ -130,14 +112,17 @@ def run_protoc(proto_file: str) -> Tuple[ModuleType, ModuleType]:
 
 def feature_definition_to_modules(fdl_node) -> Tuple[ModuleType, ModuleType]:
     xslt = XSLT(etree.parse(join(resource_dir, "xsl", "fdl2proto.xsl")))
-    proto_str = str(xslt(fdl_node))
-
     feature_id = xpath_sila(fdl_node, "sila:Identifier")[0].text
+
+    try:
+        proto_str = str(xslt(fdl_node))
+    except XSLTApplyError as ex:
+        raise ValueError(f"Invalid feature definition {feature_id}: {ex}")
+
     with tempfile.TemporaryDirectory() as tmp_dir:
         proto_file = join(tmp_dir, f"{feature_id}.proto")
         with open(proto_file, "w", encoding="utf-8") as proto_fp:
             proto_fp.write(proto_str)
-
         return run_protoc(proto_file)
 
 
@@ -151,12 +136,16 @@ def temporarily_add_to_path(*paths: str):
             sys.path.remove(path)
 
 
-def xml_node_to_normalized_string(xml_node: _Element, remove_namespace: bool = False) -> str:
+def xml_node_to_normalized_string(xml_node: Union[str, _Element], remove_namespace: bool = False) -> str:
+    if isinstance(xml_node, str):
+        xml_node = etree.fromstring(xml_node)
+
     if remove_namespace:
         str_with_namespace = etree.tostring(xml_node).decode("utf-8")
         str_without_namespace = re.sub(r"^<(\w+).*?>", r"<\1>", str_with_namespace)
         node_without_namespace = etree.fromstring(str_without_namespace)
         return etree.tostring(node_without_namespace, method="c14n2", strip_text=True).decode("utf-8")
+
     return etree.tostring(xml_node, method="c14n2", strip_text=True).decode("utf-8")
 
 
