@@ -54,10 +54,13 @@ class FeatureImplementationServicer:
         self.observable_property_subscription_managers = {}
         self.logger = logging.getLogger(feature._identifier)
 
-    def _set_implementation(self, implementation: FeatureImplementationBase):
+    def start(self):
+        self.__start_observable_property_listeners()
+        self.implementation.start()
+
+    def set_implementation(self, implementation: FeatureImplementationBase):
         self.logger.debug(f"Setting implementation to {implementation}")
         self.implementation = implementation
-        self.__start_observable_property_listeners()
 
         for prop in self.feature._unobservable_properties.values():
             setattr(self, f"Get_{prop._identifier}", self.__get_unobservable_property_get_call(prop._identifier))
